/***************************************************************************************
 *
 *  IMPORTANT: READ BEFORE DOWNLOADING, COPYING, INSTALLING OR USING.
 *
 *  By downloading, copying, installing or using the software you agree to this license.
 *  If you do not agree to this license, do not download, install, 
 *  copy or use the software.
 *
 *  Copyright (C) 2014-2024, Happytimesoft Corporation, all rights reserved.
 *
 *  Redistribution and use in binary forms, with or without modification, are permitted.
 *
 *  Unless required by applicable law or agreed to in writing, software distributed 
 *  under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 *  CONDITIONS OF ANY KIND, either express or implied. See the License for the specific
 *  language governing permissions and limitations under the License.
 *
****************************************************************************************/

#ifndef ONVIF_ACT_H
#define ONVIF_ACT_H

/*************************************************************************/
typedef enum 
{
	eActionNull = 0,

    // onvif device service interfaces		
	etdsGetCapabilities,
	etdsGetServices,
	etdsGetServiceCapabilities,
	etdsGetDeviceInformation,
	etdsGetUsers,
	etdsCreateUsers,
	etdsDeleteUsers,
	etdsSetUser,
	etdsGetRemoteUser,
	etdsSetRemoteUser,
	etdsGetNetworkInterfaces,
	etdsSetNetworkInterfaces,
	etdsGetNTP,
	etdsSetNTP,
	etdsGetHostname,
	etdsSetHostname,
	etdsSetHostnameFromDHCP,
	etdsGetDNS,
	etdsSetDNS,
	etdsGetDynamicDNS,
	etdsSetDynamicDNS,
	etdsGetNetworkProtocols,
	etdsSetNetworkProtocols,
	etdsGetDiscoveryMode,
	etdsSetDiscoveryMode,
	etdsGetNetworkDefaultGateway,
	etdsSetNetworkDefaultGateway,
	etdsGetZeroConfiguration,
	etdsSetZeroConfiguration,
	etdsGetEndpointReference,	
	etdsSendAuxiliaryCommand,	
	etdsGetRelayOutputs,
	etdsSetRelayOutputSettings,
	etdsSetRelayOutputState,
	etdsGetSystemDateAndTime,
	etdsSetSystemDateAndTime,
	etdsSystemReboot,
	etdsSetSystemFactoryDefault,
	etdsGetSystemLog,
	etdsGetScopes,
	etdsSetScopes,
	etdsAddScopes,
	etdsRemoveScopes,
    etdsStartFirmwareUpgrade,
    etdsGetSystemUris,
    etdsStartSystemRestore,
    etdsGetWsdlUrl,
    etdsGetDot11Capabilities,
    etdsGetDot11Status,
    etdsScanAvailableDot11Networks,
    etdsGetGeoLocation,
    etdsSetGeoLocation,
    etdsDeleteGeoLocation,
    etdsSetHashingAlgorithm,
    etdsGetIPAddressFilter,
    etdsSetIPAddressFilter,
    etdsAddIPAddressFilter,
    etdsRemoveIPAddressFilter,
    etdsGetAccessPolicy,
    etdsSetAccessPolicy,
    etdsGetStorageConfigurations,
    etdsCreateStorageConfiguration,
    etdsGetStorageConfiguration,
    etdsSetStorageConfiguration,
    etdsDeleteStorageConfiguration,

    // onvif media service interfaces
    etrtGetServiceCapabilities,
    etrtGetVideoSources,
    etrtGetAudioSources,
    etrtCreateProfile,
    etrtGetProfile,
    etrtGetProfiles,
    etrtAddVideoEncoderConfiguration,
    etrtAddVideoSourceConfiguration,
    etrtAddAudioEncoderConfiguration,
    etrtAddAudioSourceConfiguration,
    etrtGetVideoSourceModes,
    etrtSetVideoSourceMode,
    etrtAddPTZConfiguration,
    etrtRemoveVideoEncoderConfiguration,
    etrtRemoveVideoSourceConfiguration,
    etrtRemoveAudioEncoderConfiguration,
    etrtRemoveAudioSourceConfiguration,
    etrtRemovePTZConfiguration,
    etrtDeleteProfile,
    etrtGetVideoSourceConfigurations,
    etrtGetVideoEncoderConfigurations,	
    etrtGetAudioSourceConfigurations,
    etrtGetAudioEncoderConfigurations,
    etrtGetVideoSourceConfiguration,
    etrtGetVideoEncoderConfiguration,
    etrtGetAudioSourceConfiguration,
    etrtGetAudioEncoderConfiguration,
    etrtSetVideoSourceConfiguration,
    etrtSetVideoEncoderConfiguration,	
    etrtSetAudioSourceConfiguration,
    etrtSetAudioEncoderConfiguration,
    etrtGetVideoSourceConfigurationOptions,
    etrtGetVideoEncoderConfigurationOptions,	
    etrtGetAudioSourceConfigurationOptions,
    etrtGetAudioEncoderConfigurationOptions,	
    etrtGetStreamUri,	
    etrtSetSynchronizationPoint,
    etrtGetSnapshotUri,
    etrtGetGuaranteedNumberOfVideoEncoderInstances,
    etrtGetAudioOutputs,
    etrtGetAudioOutputConfigurations,
    etrtGetAudioOutputConfiguration,
    etrtGetAudioOutputConfigurationOptions,
    etrtSetAudioOutputConfiguration,
    etrtGetAudioDecoderConfigurations,
    etrtGetAudioDecoderConfiguration,
    etrtGetAudioDecoderConfigurationOptions,
    etrtSetAudioDecoderConfiguration,
    etrtAddAudioOutputConfiguration,
    etrtAddAudioDecoderConfiguration,
    etrtRemoveAudioOutputConfiguration,
    etrtRemoveAudioDecoderConfiguration,
    etrtGetOSDs,
    etrtGetOSD,
    etrtSetOSD,
    etrtGetOSDOptions,
    etrtCreateOSD,
    etrtDeleteOSD,
    etrtGetVideoAnalyticsConfigurations,
    etrtAddVideoAnalyticsConfiguration,
    etrtGetVideoAnalyticsConfiguration,
    etrtRemoveVideoAnalyticsConfiguration,
    etrtSetVideoAnalyticsConfiguration,
    etrtGetMetadataConfigurations,
    etrtAddMetadataConfiguration,
    etrtGetMetadataConfiguration,
    etrtRemoveMetadataConfiguration,
    etrtSetMetadataConfiguration,
    etrtGetMetadataConfigurationOptions,
    etrtGetCompatibleVideoEncoderConfigurations,
    etrtGetCompatibleAudioEncoderConfigurations,
    etrtGetCompatibleVideoAnalyticsConfigurations,
    etrtGetCompatibleMetadataConfigurations,

    // onvif media 2 service interfaces
    etr2GetServiceCapabilities,
    etr2GetVideoEncoderConfigurations,
    etr2SetVideoEncoderConfiguration,
    etr2GetVideoEncoderConfigurationOptions,
    etr2GetProfiles,
    etr2CreateProfile,
    etr2DeleteProfile,
    etr2GetStreamUri,
    etr2GetVideoSourceConfigurations,
    etr2GetVideoSourceConfigurationOptions,
    etr2SetVideoSourceConfiguration,
    etr2SetSynchronizationPoint,
    etr2GetMetadataConfigurations,
    etr2GetMetadataConfigurationOptions,
    etr2SetMetadataConfiguration,
    etr2GetAudioEncoderConfigurations,
    etr2GetAudioSourceConfigurations,
    etr2GetAudioSourceConfigurationOptions,
    etr2SetAudioSourceConfiguration,
    etr2SetAudioEncoderConfiguration,
    etr2GetAudioEncoderConfigurationOptions,
    etr2AddConfiguration,
    etr2RemoveConfiguration,
    etr2GetVideoEncoderInstances,
    etr2GetAudioOutputConfigurations,
    etr2GetAudioOutputConfigurationOptions,
    etr2SetAudioOutputConfiguration,
    etr2GetAudioDecoderConfigurations,
    etr2GetAudioDecoderConfigurationOptions,
    etr2SetAudioDecoderConfiguration,
    etr2GetSnapshotUri,
    etr2StartMulticastStreaming,
    etr2StopMulticastStreaming,
    etr2GetVideoSourceModes,
    etr2SetVideoSourceMode,
    etr2CreateOSD,
    etr2DeleteOSD,
    etr2GetOSDs,
    etr2SetOSD,
    etr2GetOSDOptions,
    etr2GetAnalyticsConfigurations,
    etr2GetMasks,
    etr2SetMask,
    etr2CreateMask,
    etr2DeleteMask,
    etr2GetMaskOptions,

    // onvif ptz service interfaces
    eptzGetServiceCapabilities,
	eptzGetNodes,
	eptzGetNode,
	eptzGetPresets,
	eptzSetPreset,
	eptzRemovePreset,
	eptzGotoPreset,
	eptzGotoHomePosition,
	eptzSetHomePosition,
	eptzGetStatus,
	eptzContinuousMove,
	eptzRelativeMove,
	eptzAbsoluteMove,
	eptzStop,
	eptzGetConfigurations,
	eptzGetConfiguration,
	eptzSetConfiguration,	
	eptzGetConfigurationOptions,
	eptzGetPresetTours,
	eptzGetPresetTour,
	eptzGetPresetTourOptions,
	eptzCreatePresetTour,
	eptzModifyPresetTour,
	eptzOperatePresetTour,
	eptzRemovePresetTour,
	eptzSendAuxiliaryCommand,
	eptzGeoMove,

    // onvif event service interfaces
    etevGetServiceCapabilities,
	etevGetEventProperties,
	etevRenew,
	etevUnsubscribe,
	etevSubscribe,
	etevPauseSubscription,
	etevResumeSubscription,
    etevCreatePullPointSubscription,
    etevDestroyPullPoint,
    etevPullMessages,
    etevGetMessages,
    etevSeek,
    etevSetSynchronizationPoint,

	// onvif imaging service interfaces
	eimgGetServiceCapabilities,
	eimgGetImagingSettings,
	eimgSetImagingSettings,
	eimgGetOptions,
	eimgMove,
	eimgStop,
	eimgGetStatus,
	eimgGetMoveOptions,
	eimgGetPresets,
	eimgGetCurrentPreset,
	eimgSetCurrentPreset,

    // onvif device IO service interfaces
    etmdGetServiceCapabilities,
    etmdGetRelayOutputs,
    etmdGetRelayOutputOptions,
    etmdSetRelayOutputSettings,
    etmdSetRelayOutputState,
    etmdGetDigitalInputs,
    etmdGetDigitalInputConfigurationOptions,
    etmdSetDigitalInputConfigurations,

    // onvif recording service interfaces
    etrcGetServiceCapabilities,
    etrcCreateRecording,
    etrcDeleteRecording,
    etrcGetRecordings,
    etrcSetRecordingConfiguration,
    etrcGetRecordingConfiguration,
    etrcGetRecordingOptions,
    etrcCreateTrack,
    etrcDeleteTrack,
    etrcGetTrackConfiguration,
    etrcSetTrackConfiguration,
    etrcCreateRecordingJob,
    etrcDeleteRecordingJob,
    etrcGetRecordingJobs,
    etrcSetRecordingJobConfiguration,
    etrcGetRecordingJobConfiguration,
    etrcSetRecordingJobMode,
    etrcGetRecordingJobState,
    etrcExportRecordedData,
    etrcStopExportRecordedData,
    etrcGetExportRecordedDataState,
    
    // onvif replay service interfaces
    etrpGetServiceCapabilities,
	etrpGetReplayUri,
	etrpGetReplayConfiguration,
	etrpSetReplayConfiguration,

    // onvif search service interfaces
    etseGetServiceCapabilities,
	etseGetRecordingSummary,
	etseGetRecordingInformation,
	etseGetMediaAttributes,
	etseFindRecordings,
	etseGetRecordingSearchResults,
	etseFindEvents,
	etseGetEventSearchResults,
	etseFindMetadata,
	etseGetMetadataSearchResults,
	etseFindPTZPosition,
	etseGetPTZPositionSearchResults,
	etseGetSearchState,
	etseEndSearch,

	// onvif analytics service interfaces
	etanGetServiceCapabilities,
	etanGetSupportedRules,
	etanCreateRules,
	etanDeleteRules,
	etanGetRules,
	etanModifyRules,
	etanCreateAnalyticsModules,
	etanDeleteAnalyticsModules,
	etanGetAnalyticsModules,
	etanModifyAnalyticsModules,
	etanGetSupportedAnalyticsModules,
	etanGetRuleOptions,
	etanGetAnalyticsModuleOptions,
	etanGetSupportedMetadata,
	
    // onvif access control service interface
    etacGetServiceCapabilities,
	etacGetAccessPointInfoList,
    etacGetAccessPointInfo,
    etacGetAccessPointList,
    etacGetAccessPoints,
    etacCreateAccessPoint,
    etacSetAccessPoint,
    etacModifyAccessPoint,
    etacDeleteAccessPoint,
    etacGetAreaInfoList,
    etacGetAreaInfo,
    etacGetAreaList,
    etacGetAreas,
    etacCreateArea,
    etacSetArea,
    etacModifyArea,
    etacDeleteArea,
    etacGetAccessPointState,
    etacEnableAccessPoint,
    etacDisableAccessPoint,

    // onvif door control service interface
    etdcGetServiceCapabilities,
    etdcGetDoorInfoList,
    etdcGetDoorInfo,    
    etdcGetDoorState,
    etdcAccessDoor,
    etdcLockDoor,
    etdcUnlockDoor,
    etdcDoubleLockDoor,
    etdcBlockDoor,
    etdcLockDownDoor,
    etdcLockDownReleaseDoor,
    etdcLockOpenDoor,
    etdcLockOpenReleaseDoor,
    etdcGetDoors,
    etdcGetDoorList,
    etdcCreateDoor,
    etdcSetDoor,
    etdcModifyDoor,
    etdcDeleteDoor,

    // onvif thermal service interfaces
    etthGetServiceCapabilities,
    etthGetConfigurations,
    etthGetConfiguration,
    etthSetConfiguration,
    etthGetConfigurationOptions,
    etthGetRadiometryConfiguration,
    etthSetRadiometryConfiguration,
    etthGetRadiometryConfigurationOptions,

    // onvif credential service interfaces
    etcrGetServiceCapabilities,
    etcrGetCredentialInfo,
    etcrGetCredentialInfoList,
    etcrGetCredentials,
    etcrGetCredentialList,
    etcrCreateCredential,
    etcrModifyCredential,
    etcrDeleteCredential,
    etcrGetCredentialState,
    etcrEnableCredential,
    etcrDisableCredential,
    etcrResetAntipassbackViolation,
    etcrGetSupportedFormatTypes,
    etcrGetCredentialIdentifiers,
    etcrSetCredentialIdentifier,
    etcrDeleteCredentialIdentifier,
    etcrGetCredentialAccessProfiles,
    etcrSetCredentialAccessProfiles,
    etcrDeleteCredentialAccessProfiles,

    // onvif access rules service interfaces
    etarGetServiceCapabilities,
    etarGetAccessProfileInfo,
    etarGetAccessProfileInfoList,
    etarGetAccessProfiles,
    etarGetAccessProfileList,
    etarCreateAccessProfile,
    etarModifyAccessProfile,
    etarDeleteAccessProfile,    

    // onvif schedule service interface
    etscGetServiceCapabilities,
    etscGetScheduleInfo,
    etscGetScheduleInfoList,
    etscGetSchedules,
    etscGetScheduleList,
    etscCreateSchedule,
    etscModifySchedule,
    etscDeleteSchedule,
    etscGetSpecialDayGroupInfo,
    etscGetSpecialDayGroupInfoList,
    etscGetSpecialDayGroups,
    etscGetSpecialDayGroupList,
    etscCreateSpecialDayGroup,
    etscModifySpecialDayGroup,
    etscDeleteSpecialDayGroup,
    etscGetScheduleState,

    // onvif receiver service interface
    etrvGetServiceCapabilities,
    etrvGetReceivers,
    etrvGetReceiver,
    etrvCreateReceiver,
    etrvDeleteReceiver,
    etrvConfigureReceiver,
    etrvSetReceiverMode,
    etrvGetReceiverState,

    // onvif provisioning service interface
    etpvGetServiceCapabilities,
    etpvPanMove,
    etpvTiltMove,
    etpvZoomMove,
    etpvRollMove,
    etpvFocusMove,
    etpvStop,
    etpvGetUsage,

	eActionMax
} eOnvifAction;

typedef struct
{
	eOnvifAction	type;
	char			action_url[256];
} OVFACTS;

#ifdef __cplusplus
extern "C" {
#endif

HT_API OVFACTS * onvif_find_action_by_type(eOnvifAction type);

#ifdef __cplusplus
}
#endif

#endif


